pub type OriginalSyncCallInviteEvent = OriginalSyncMessageLikeEvent<CallInviteEventContent>;Expand description
An m.call.invite event from a sync_events response.
Aliased Type
pub struct OriginalSyncCallInviteEvent {
pub content: CallInviteEventContent,
pub event_id: OwnedEventId,
pub sender: OwnedUserId,
pub origin_server_ts: MilliSecondsSinceUnixEpoch,
pub unsigned: MessageLikeUnsigned<CallInviteEventContent>,
pub sticky: Option<StickyObject>,
}Fields
content: CallInviteEventContentData specific to the event type.
event_id: OwnedEventIdThe globally unique identifier for the event.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
origin_server_ts: MilliSecondsSinceUnixEpochTimestamp on the originating homeserver when this event was sent.
unsigned: MessageLikeUnsigned<CallInviteEventContent>Additional key-value pairs not signed by the homeserver.
sticky: Option<StickyObject>Message events can be annotated with a new top-level sticky object, which MUST have a duration_ms, which is the number of milliseconds for the event to be sticky.